/*********************************************************
	Make Transition Matrix
	
	----------------------------------
	
	The transition matrix is a linear transformation that describes
	how circles should be crosswalked.
		
*********************************************************/

clear all
cap cd "$PAKTAX2_ANALYSIS"

****************************************************

// Arguments
// -- q = starting quarter
// -- y = starting year
// -- type = c (current) or a (arrears)
// -- direction = 0 (forwards) or 1 (backwards)

// ALSO: circles = list of circles in starting year to be crosswalked (global)
//		[Stata won't let you pass a string with a comma as an argument, so a global is a work-around]

args q y type direction  

// Next quarter and next year in a way that loops around
if `direction' == 0 {
	local q2 = mod(`q', 4) + 1
	local y2 = `y' + floor(`q' / 4)
}
else if `direction' == 1 {
	local y2 = `y' - floor(1 / `q')
	local q2 = `q' - 1 + (4 * floor(1 / `q'))	
}

pause off // For debugging

******************************************************

/*
	NOTES
	
	STRUCTURE
	1. Group Circles into Robust Partitions.
		
		A robust partition is the group of circles that are involved in a transition from
		one quarter to next. For example: A and B merge to form C; A splits to form B
		and C; A, B, and C go through a complex change to form D and E.
		
	2. Focus on circles that need to be crosswalked
		
		Circles with a robust partition size of 1 don't need to be crosswalked. Also
		new circles (out of thin air) don't need to be crosswalked either. We put them
		aside and take their values as is. If there's no crosswalking necessary, merge 
		current data with the previous crosswalk and save it.
		
	3. Crosswalk data, one robust partition at a time
	
		We use the "linear algebra" technique, outlined in the latest version of 
	
			Pakistan Property Tax Project/Documentation/XXXX crosswalk_readme.pdf
	
		Basically we construct a transition matrix T that we apply to the vector
		of each historical values (by quarter) in order obtain crosswalked values.
		The transition matrix has free / unknown parameters if the system involves a
		split (or more) and so we need to solve for those.
		
*/


* Transition data with splits and merges.
* The rows uniquely identify circles at year y quarter q
* The columns are the various circles that those circles are splitting into
* I.e. the name of the final is where we "end up" after the crosswalk
if `direction' == 0 {
	insheet using "Data/Raw Data/Administrative Data/Crosswalk/`y2'_q`q2'_transition.csv", comma clear

	reshape long q`q2'_`y2'_circle_id, i(q`q'_`y'_circle_id) j(splits)
	drop if q`q2'_`y2'_circle_id == .
}
else if `direction' == 1 {
	insheet using "Data/Raw Data/Administrative Data/Crosswalk//`y'_q`q'_transition.csv", comma clear

	reshape long q`q'_`y'_circle_id, i(q`q2'_`y2'_circle_id) j(splits)
	drop if q`q'_`y'_circle_id == .
	drop splits

	order q`q'_`y'_circle_id q`q2'_`y2'_circle_id
	bys q`q'_`y'_circle_id (q`q2'_`y2'_circle_id) : gen splits = _n
}


* Choose the current robust partition of interest
keep if inlist(q`q'_`y'_circle_id, ${circles})

keep q`q'_`y'_circle_id q`q2'_`y2'_circle_id 
duplicates drop

sort q`q'_`y'_circle_id q`q2'_`y2'_circle_id 
by q`q'_`y'_circle_id : gen splits = _n

egen num_splits = max(splits), by(q`q'_`y'_circle_id)

// First make sure that split circles are sorted in the same order
drop splits
sort q`q'_`y'_circle_id q`q2'_`y2'_circle_id
bys q`q'_`y'_circle_id : gen splits = _n

reshape wide q`q2'_`y2'_circle_id, i(q`q'_`y'_circle_id) j(splits)
duplicates tag q`q2'_`y2'_circle_id*, generate(duplicate_splits)

assert duplicate_splits == 0 if num_splits > 1
drop duplicate_splits

// Reshape back to long after duplicates check
reshape long

// This is the data that we'll be looping over
tempfile main
save `main'

* -- Solve for transition matrix T

*** First define mata functions
mata : mata clear
do "Data/Do Files/Administrative Data/Mata Functions.do"

use `main', clear

qui tab q`q'_`y'_circle_id
local n = `r(r)' // Number of starting circles (the A's)
di "Number of starting circles (the A's) : `n'"


qui tab q`q2'_`y2'_circle_id
local m = `r(r)'	// Number of resulting circles (the B's)
di "Number of resulting circles (the B's) : `m'"

pause

tempfile currentrobustpartition
save `currentrobustpartition'

preserve
	reshape wide q`q2'_`y2'_circle_id, i(q`q'_`y'_circle_id) j(splits)
	qui sum num_splits
	local k = `r(sum)' - `n' // Number of free parameters in T that we need to solve for
restore

di "Number of free parameters: `k'"

pause

// Sorts are critical, that's how we know which circles the columns and rows of T refer to
sort q`q'_`y'_circle_id q`q2'_`y2'_circle_id		
qui tab q`q2'_`y2'_circle_id, generate(B)

keep q`q'_`y'_circle_id num_splits B*
collapse num_splits (max) B*, by(q`q'_`y'_circle_id)

reshape long B, i(q`q'_`y'_circle_id ) j(index)
drop if B == 0

egen finalsplit = max(index), by(q`q'_`y'_circle_id)

reshape wide

order num_splits finalsplit B*, first

mata : M0 = makeM0(`m', `n', `k')
mata : M0

if `k'>0 {
	mata : M = makeMv2(`m', `n', `k')
	mata : M
}
	
* Get "a" vector -- list of starting current net demand
* This is always net demand, regardless of whether we're crosswalking other values
* But it'll be net_dem_c for current values and net_dem_a for arrears values
	
use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y' Q`q'/FY`y' Q`q'.dta", clear
keep circle_id net_dem_`type'
keep if inlist(circle_id, ${circles})

order circle_id net_dem_`type'
rename circle_id q`q'_`y'_circle_id
duplicates drop

sort q`q'_`y'_circle_id 
list
keep net_dem_`type'

*Make sure we have everyone
qui count
assert `r(N)' == `n'

mata : a = st_data(., 1)

* Get "b" vector -- list of ending current net demand
use "Data/Cleaned Data/Administrative Data/Punjab Compiled - Quarterly.dta", clear

keep if fyear == `y2' & qtr == `q2'
rename circle_id q`q2'_`y2'_circle_id
duplicates drop
merge 1:m q`q2'_`y2'_circle_id using `currentrobustpartition'
keep if _merge == 3
drop _merge

keep q`q2'_`y2'_circle_id net_dem_`type'
duplicates drop
sort q`q2'_`y2'_circle_id
list
keep net_dem_`type'
	
*Make sure we have everyone
qui count
assert `r(N)' == `m'

mata : b = st_data(., 1)
	
// Assign transition matrix; solve if necessary
if `k' == 0  mata : T = M0

if `k' > 0 {
	mata : calculateT(`n', `k', M0, M, a, b, T=.)
}

di "Transition Matrix for robust partition `rp' going from Q`q' Y`y' to Q`q2' Y`y2'"
mata : T
mata : st_matrix("T", T)
pause
