********************************************************************
*Calculate Inspector Ranks - FY 2014 Q4 - Demand rank for all control inspectors

clear all
set more off
cap cd "$PAKTAX2_ANALYSIS"

********************************************************************


********************************************************************
* 1. Calculate Inspector HR
* a. Get a list of inspectors in the program, handle additional charges
* b. Drop inspector in litigated circle
* c. Calculate the fraction of time they 
*    were in each circle, so that we can pro-rate performance
********************************************************************

* Declare local variables here
local q_latest = 4					// Set to latest quarter
local y_latest = 2014
local y_prev = 2013
local days_in_qtr 92 92 90 91
local q_day_start 1 1 1 1
local q_day_end 30 31 31 30
local q_month_start 7 10 1 4
local q_month_end 9 12 3 6
local q_year 2013 2013 2014 2014
local missing_fin_score_code = -9999
local preference_sim_seed = 405904

* Declare input file paths
local baseline_preferences_all = "TP Analysis/Coded Data/Cleaned baseline preferences"
local crosswalk_all = "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv"
local litigated_circles_file = "Data/Raw Data/Administrative Data/Circles under litigation.csv"
local hr_q1_2014_file = "Data/Raw Data/Current HR Confirmation/131028 HR Verification FY2014Q1/150109 HR Verification Q1 Inspectors.csv"
local hr_q2_2014_file = "Data/Raw Data/Current HR Confirmation\140414 HR Verification FY2014 Q2-Q3/150109 HR Verification Q2 Inspectors.csv"
local hr_q3_2014_file = "Data/Raw Data/Current HR Confirmation/140414 HR Verification FY2014 Q2-Q3/150108 HR Verification Q3 Inspectors.csv"
local hr_q4_2014_file = "Data/Raw Data/Current HR Confirmation/140630 HR Verification FY2014 Q4/150109 HR Verification Q4.csv"
local revenue_data_dir = "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/"
local y1_data= "TP Analysis\Coded Data/Analysis Data with Lags"

******************************************************************************
* 1. Load and save litigated circles
******************************************************************************

insheet using "Data/Raw Data/Administrative Data/Circles under litigation.csv", comma clear
keep if fyear == 2014 & qtr == 4
keep circle_id
tempfile litigation
save `litigation'

insheet using "`litigated_circles_file'", comma clear // TODO: look into litigated circles, and check if any ins moved to one
keep if fyear == `y_latest'
keep circle_id
duplicates drop
tempfile litigation_all
save `litigation_all'

******************************************************************************
* 2. Inspectors
******************************************************************************

*Identify Control inspectors

*1. Baseline preferences

use "`baseline_preferences_all'", clear // This is the correct source for partition_id, treated&control inspectors, etc.
keep if own_circle==1
keep hr_id partition_name  group circle_id 
tempfile control_ins
save `control_ins'

*2. Y1 location

use "`y1_data'"
drop if qtr!=4
drop if treatment_y1==1 | treatment_y1==.
tempfile control_ins_2
save `control_ins_2'

*3. Treated inspectors

use "Data/Raw Data\Current HR Confirmation\131124 Stage II Treatment Staff", clear
keep hr_id
duplicates drop
drop if hr_id==40871 // part of the earlier cleaning
tempfile treatment
save `treatment'
merge 1:m hr_id using `control_ins', keep(2) nogen
save `control_ins', replace

// Drop inspector in circle under litigation
merge m:1 circle_id using `litigation', keep(1) nogen
duplicates drop circle_id, force

rename circle_id balloted_circle_id

keep partition_name hr_id group balloted_circle_id 
duplicates report hr_id
duplicates tag hr_id, gen(count)
tempfile inspectors
save `inspectors'

preserve
drop if count==0
rename balloted_circle_id circle_id
merge 1:1 hr_id circle_id using `control_ins_2', keepusing(ins_ac ) keep(3)
keep hr_id circle_id ins_ac
rename circle_id balloted_circle_id
tempfile ins_ac
save `ins_ac'
restore

merge 1:1 balloted_circle_id hr_id using `ins_ac', keep(1 3) nogen
drop if ins_ac==1
duplicates tag hr_id, gen(cc)
drop if hr_id==41001 & balloted_circle_id==408103
drop if hr_id==50005 & balloted_circle_id==500900
drop if hr_id==60217 & balloted_circle_id==611301

duplicates report hr_id
rename ins_ac balloted_ac
save `inspectors', replace

******************************************************************************
* 3. Load & save HR data for each quarter
******************************************************************************

forval q = 1/`q_latest' {
	
	* Load file corresponding to quarter
	local curr_hr: word `q' of "`hr_q1_2014_file'" "`hr_q2_2014_file'" "`hr_q3_2014_file'" "`hr_q4_2014_file'"
	insheet using "`curr_hr'", comma clear
	*drop cons_1-eto_transferin

	/*
	Apply basic data cleaning
	*/
	drop if mi(circle_id)

	* Ensure that hr ID is not missing if circle is not vacant
	assert !mi(hr_id1) if ins1 != "" & ins1 != "VACANT"
	assert !mi(hr_id2) if ins2 != "" & ins2 != "VACANT"
	*assert !mi(hr_id3) if ins3 != "" & ins3 != "VACANT"

	* Convert start* and end* to string vars
	tostring start*, replace
	tostring end*, replace
	replace start1 = "" if mi(start1) | start1 == "."
	replace start2 = "" if mi(start2) | start2 == "."
	*replace start3 = "" if mi(start3) | start3 == "."
	replace end1 = "" if mi(end1) | end1 == "."
	replace end2 = "" if mi(end2) | end2 == "."
	*replace end3 = "" if mi(end3) | end3 == "."
	
	gen qtr = `q'
	gen fyear = `y_latest'

	tempfile hr_q`q'_`y_latest'
	save `hr_q`q'_`y_latest''
}

clear all
tempfile hr_all
sa `hr_all', emptyok

* Compile all HR data and reshape
forval q = 1/`q_latest' {
	append using `hr_q`q'_`y_latest''
}
reshape long hr_id ins start end ins_ac, i(circle_id qtr inspector) j(j)
drop ins
drop if hr_id == .

tempfile treatment_hr_all
sa `treatment_hr_all'

******************************************************************************
* 6. Calculate time in circles for each inspector
******************************************************************************

* Enter actual start and end dates (instead of blanks)
forval q = 1/`q_latest' {
	local q_d_start:	word `q' of `q_day_start'
	local q_d_end: 		word `q' of `q_day_end'
	local q_m_start:	word `q' of `q_month_start'
	local q_m_end:		word `q' of `q_month_end'
	local q_yr:			word `q' of `q_year'

	replace start = "`q_d_start'.`q_m_start'.`q_yr'" 	if start == "" 	& qtr == `q'
	replace end = 	"`q_d_end'.`q_m_end'.`q_yr'" 		if end == "" 	& qtr == `q'	
}

* Convert dates from string to date types
foreach var of varlist start end {
	rename `var' `var'_temp
	gen `var' = date(`var'_temp, "DMY")
	drop `var'_temp
	format `var' %td
}



******************************************************************************

merge m:1 hr_id using `inspectors', keepusing(balloted_circle_id balloted_ac partition_name group )
drop if _merge == 1
drop _merge

bys hr_id qtr : gen circlecount = _N
*assert ins_ac == 0 | ins_ac == . if circlecount == 1 
drop if ins_ac == 1 & balloted_ac != 1
egen has_ac = total(ins_ac), by(hr_id qtr)
qui levelsof hr_id if has_ac == 0 & balloted_ac == 1, s(",")
gen keepmaincharge = .
replace keepmaincharge = 1 if hr_id == 11660
drop if ins_ac != 1 & balloted_ac == 1 & keepmaincharge != 1
drop if circle_id != balloted_circle_id & has_ac > 1
drop keepmaincharge has_ac
assert balloted_ac == 1 if ins_ac == 1


******************************************************************************


* Calculate # of days in circle
gen days_in_circle = end - start
bys hr_id qtr (start) : replace days_in_circle = days_in_circle + 1 if _n == 1 // add missing day to the first circle in the quarter

* Compute time spent in circle as fraction of time in quarter
gen fraction_in_circle = .
forval q = 1/`q_latest' {
	local total_days_in_qtr : word `q' of `days_in_qtr' // Gets the number of days for the corresponding quarter
	replace fraction_in_circle = days_in_circle / `total_days_in_qtr' if qtr == `q'
}

* Calculate total time in circle(s), in case ins was in two circles in one qtr
bys hr_id qtr: egen time_in_circles = total(fraction_in_circle)

*assert time_in_circles <= 1
tempfile treatment_inspectors_w_time
save `treatment_inspectors_w_time'

******************************************************************************
* 7. Calculate Inspector Performance
******************************************************************************

/*
First, load and prep revenue data
*/

clear all
tempfile ins_performance
sa `ins_performance', emptyok

* Compile all revenue data into one tempfile
forval q = 1/`q_latest' {
	use "`revenue_data_dir'/`y_latest'_q`q'_crosswalk.dta", clear
	gen qtr = `q'
	append using `ins_performance'
	sa `ins_performance', replace
}

* Generate new variables, then assign values to them in for loop
gen net_demand = .
gen delta_net_dem_c_`y_latest' = .
gen delta_net_dem_c_`y_prev' = .

forval q = 1/`q_latest' {

	* Total demand for the quarter
	*gen q`q'_`y_latest'_net_dem_c = 	q`q'_`y_latest'_net_dem_a + q`q'_`y_latest'_net_dem_c
	*gen q`q'_`y_prev'_net_dem_c = 	q`q'_`y_prev'_net_dem_a 	+ q`q'_`y_prev'_net_dem_c
	replace net_demand = q`q'_`y_latest'_net_dem_c if qtr == `q'
	
	* Special case for circle 205800
	replace q1_`y_prev'_net_dem_c = 0 if circle_id == 205800
	
	* Calculate difference between current quarter and previous quarter (within same year)
	if `q' == 1 { // Q1 must be compared to zero, not to previous quarter
		replace delta_net_dem_c_`y_latest' = 	q`q'_`y_latest'_net_dem_c - 0 if qtr == `q'
		replace delta_net_dem_c_`y_prev' = 	q`q'_`y_prev'_net_dem_c - 0 	if qtr == `q'
	}
	else {
		replace delta_net_dem_c_`y_latest' = 	q`q'_`y_latest'_net_dem_c - q`=`q'-1'_`y_latest'_net_dem_c 	if qtr == `q'
		replace delta_net_dem_c_`y_prev' = 	q`q'_`y_prev'_net_dem_c 	- q`=`q'-1'_`y_prev'_net_dem_c	if qtr == `q'
	}
}

keep circle_id qtr delta* net_demand
sa `ins_performance', replace


/*
Next, map inspectors to circles from revenue data
*/

merge 1:m circle_id qtr using `treatment_inspectors_w_time',  keep(match) nogen // Keep only matched circles
drop district j inspector ins_ac start days_in_circle

* Calculate # of circles inspectors spend time in, then merge with revenue data
preserve
	keep hr_id circle_id
	duplicates drop
	bys hr_id: gen circlecount = _N
	keep hr_id circlecount
	duplicates drop
	
	tempfile circlecount
	save `circlecount'
restore

merge m:1 hr_id using `circlecount', assert(match) nogen

* Compute performance and benchmark
gen performance = delta_net_dem_c_`y_latest' * fraction_in_circle
gen benchmark = delta_net_dem_c_`y_prev' * fraction_in_circle 
replace performance = . if benchmark == . // Correct for missing values
replace benchmark = . if performance == .

* Compute total score and benchmark for each inspector
bys hr_id: egen score = total(performance), missing // Missing only if all are missing
bys hr_id: egen bench = total(benchmark), missing
keep hr_id score bench 
*keep hr_id score bench circlecount
duplicates drop
isid hr_id
	
/*
* Remove excluded inspectors
merge 1:1 hr_id using `all_exclusions', keep(1) nogen
*/

* Calculate scores for inspectors
gen final_score = (score / bench) - 1
*replace final_score = final_score * 100
*replace final_score = `missing_fin_score_code' if final_score == . // Not enough data to rank

tempfile rankings
save `rankings'

******************************************************************************
* 7. Identify the inspectors we care about
******************************************************************************

*Getting info on inspector's group
use "`inspectors'", clear
merge m:1 hr_id using "`rankings'", keep(3) nogen

egen group_id=group(partition_name group)
gsort +group_id -final_score
by group_id: gen rank = _n

*Change name so that you can merge with demand
bys partition_name group : gen groupcount = _N
foreach var in score bench final_score rank {
rename `var' `var'_dem
}

replace group_id=group_id+30
save "TP Analysis\Coded Data/FY14 Q4 DEMAND Ranks control inspectors", replace
