clear all
version 13
cap cd "$PAKTAX2_RANDOMIZATION"

********************************************************************************

*1. Create sample
use "Output/Year 2/140805 Year 1 Control Groups Main Randomization 125450.dta", clear
count
isid circle_id // circle-level data
assert !missing(stratum_id) // all strata have been assigned

/*generate group number variable so each group has a unique number across partitions*/ 
sort partition_id group 
egen assigned_group = group(partition_id group)

/*create updated treatment variable*/ 
g treatment = . 
label var treatment "treatment status for year 2 ballot" 

/*create treatment details variable*/
g details_treatment = "control in year 1" 
replace details_treatment = "excluded in year 1" if excluded == 1 | inlist(partition_id, 2, 6, 9)
label var details_treatment "details about treatment status" 

/*create ranking method variables*/ 
g ranking_method = "" 
g ranking_method_num = . // demand == 1, recovery == 2 
label define rank 1 "DEMAND" 2 "RECOVERY"
label values ranking_method_num rank 

/*drop previous randomization variables*/
cap drop rand1 rank1

/*sort*/ 
sort partition_id assigned_group circle_id

********************************************************************************
*2. Allocate groups into Year 2 treatment/control 

**Select seed for ballot 
noisily display "Enter the number chosen by ballot: " _request(SEEDINPUT)
display "$SEEDINPUT"
set seed $SEEDINPUT
set sortseed $SEEDINPUT

*************Lahore A & B (partition_id == 5) **********************

/*randomly select 2 groups for treatment*/

**randomly order groups in Lahore A & B 
sort partition_id assigned_group circle_id 
by partition_id assigned_group: g rand_lahore = runiform() if _n == 1 & inlist(partition_id, 5)  
egen rank_lahore = rank(rand_lahore), unique // rank groups in lahore
by partition_id assigned_group: egen temp = max(rank_lahore)  
replace rank_lahore = temp 
drop temp 

**assign first two groups to treatment
replace treatment = 1 if inlist(rank_lahore, 1, 2)

**assign ranking methods to treatment groups
replace ranking_method = "RECOVERY" if rank_lahore == 1
replace ranking_method = "DEMAND" if rank_lahore == 2 

*************Lahore C, DG Khan, Sahiwal (partition_id == 2, 6, 9) **********************

/*rank Lahore C & DG Khan and assign DG Khan's rank to Sahiwal*/
sort partition_id assigned_group circle_id
by partition_id: g rand_excluded_div = runiform() if _n == 1 & inlist(partition_id, 2, 6) 
egen rank_excluded_div = rank(rand_excluded_div), unique // rank DG Khan and Lahore C
by partition_id: egen temp = max(rank_excluded_div) 
replace rank_excluded_div = temp
drop temp

sum rank_excluded_div if partition_id == 2 // DG Khan's rank
replace rank_excluded_div = `r(mean)' if partition_id == 9 // assign to Sahiwal

/*randomly order groups in the previously excluded divisions*/ 
sort partition_id assigned_group circle_id
by partition_id assigned_group: g rand_lahoreC = runiform() if _n == 1 & partition_id == 6
egen rank_lahoreC = rank(rand_lahoreC), unique // rank groups within Lahore C
by partition_id assigned_group: egen temp = max(rank_lahoreC)
replace rank_lahoreC = temp
drop temp

sort partition_id assigned_group circle_id
by partition_id assigned_group: g rand_DG_Sahiwal = runiform() if _n == 1 & inlist(partition_id, 2, 9) 
egen rank_DG_Sahiwal = rank(rand_DG_Sahiwal), unique // rank groups within Lahore C
by partition_id assigned_group: egen temp = max(rank_DG_Sahiwal)
replace rank_DG_Sahiwal = temp
drop temp

/*assign treatment*/
replace treatment = 1 if rank_lahoreC == 1 
replace treatment = 1 if rank_DG_Sahiwal == 1 

/*assign ranking method*/
replace ranking_method = "RECOVERY" if treatment == 1 & rank_excluded_div == 1
replace ranking_method = "DEMAND" if treatment == 1 & rank_excluded_div == 2

************** Remaining Divisions excluding Sarghoda *******************************

/*randomly select 3 divisions out of the remaining 5 divisions*/ 

**recall that in Year2 Treatment Ballot, we assigned:
**Bahwalpur (part_id == 1), Multan (7), Pindi (8) == Demand 
**Faisalabad (3), Gujranwala (4) == Recovery 
**now we select 3 divisions from demand group for recovery and 1 division from recovery group for demand.

/*randomly order previous demand groups*/
sort partition_id assigned_group circle_id
by partition_id: g rand_div_demand = runiform() if _n == 1 & inlist(partition_id, 1, 7, 8)
egen rank_demand = rank(rand_div_demand), unique // rank prevous demand divisions
by partition_id: egen temp = max(rank_demand)
replace rank_demand = temp
drop temp

/*randomly order groups in first 2 randomly selected divisions*/ 
levelsof partition_id if rank_demand <= 2, local(selected_demand_divisions) 
foreach i of numlist `selected_demand_divisions'{
	sort partition_id assigned_group circle_id
	by partition_id assigned_group: g rand_group`i' = runiform() if _n == 1 & partition_id == `i'
	egen rank_group`i' = rank(rand_group`i'), unique // rank groups within divisions
	by partition_id assigned_group: egen temp = max(rank_group`i')
	replace rank_group`i' = temp
	drop temp
}

/*assign first group in first 2 randomly selected divisions to treatment*/ 
foreach i of numlist `selected_demand_divisions'{
	/*assign to treatment*/
	replace treatment = 1 if rank_group`i' == 1
	
	/*assign to recovery*/
	replace ranking_method = "RECOVERY" if rank_group`i' == 1
}	


/*randomly order previous recovery groups*/
sort partition_id assigned_group circle_id
by partition_id: g rand_div_recov = runiform() if _n == 1 & inlist(partition_id, 3, 4)
egen rank_recovery = rank(rand_div_recov), unique // rank previous recovery divisions
by partition_id: egen temp = max(rank_recovery)
replace rank_recovery = temp
drop temp

/*randomly order groups in first randomly selected division*/ 
levelsof partition_id if rank_recovery == 1, local(selected_recovery_divisions) 
foreach i of numlist `selected_recovery_divisions'{
	sort partition_id assigned_group circle_id
	by partition_id assigned_group: g rand_group`i' = runiform() if _n == 1 & partition_id == `i'
	egen rank_group`i' = rank(rand_group`i'), unique // rank groups within divisions
	by partition_id assigned_group: egen temp = max(rank_group`i')
	replace rank_group`i' = temp
	drop temp
}

/*assign first group in first randomly selected division to treatment*/ 
foreach i of numlist `selected_recovery_divisions'{
	/*assign to treatment*/
	replace treatment = 1 if rank_group`i' == 1
	
	/*assign to demand*/
	replace ranking_method = "DEMAND" if rank_group`i' == 1
}	
/*update treatment variable*/ 
replace treatment = 0 if missing(treatment) 

/*update treatment details variable*/
#delimit ; 
replace details_treatment = "control in year 1 & treatment in year 2" if treatment == 1 
	& details_treatment == "control in year 1" ; 
replace details_treatment = "excl. in year 1 & treatment in year 2" if treatment == 1 
	& details_treatment == "excluded in year 1" ; 
#delimit cr 
	
/*update numerical ranking method variable*/ 
replace ranking_method_num = 1 if ranking_method == "DEMAND"
replace ranking_method_num = 2 if ranking_method == "RECOVERY" 

/*checks*/ 
assert !missing(ranking_method) if treatment == 1
assert !missing(ranking_method_num) if treatment == 1 

levelsof assigned_group if treatment == 1, local(treated_groups)
local num_treat : word count `treated_groups' 
assert `num_treat' == 7 // 7 treated groups

levelsof assigned_group if ranking_method == "RECOVERY", local(recovery_groups)
local num_recovery : word count `recovery_groups'
assert `num_recovery' == 4 // 4 recovery groups

levelsof assigned_group if ranking_method == "DEMAND", local(demand_groups)
local num_demand : word count `demand_groups'
assert `num_demand' == 3 // 3 demand groups 

********************************************************************************
*3. Save files and display 

/*save files*/ 
save "Output/Year 2/140830 Control Groups Year 2 Randomization $SEEDINPUT", replace
