/*

Base growth predictions

Date created:
	Nov 22, 2017

Summary:
	Predicts base Y1 performance using time lags under 2 approaches:
	- Old: sample consists in control group
	- New: leave-one-out approach, treatment has prediction from one 
	  randomly selected control circle within the partition.
	
*/

******************************************************************************
* 0. Initial setup
******************************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

* Declare constants here

* Declare input file paths
local analysis_data =  			"Coded Data/Analysis Data with Lags"

* Declare output file paths
local output_file_old = 			"Coded Data/base_growth_predictions_old"
local output_file_new = 			"Coded Data/base_growth_predictions_new"

set seed 111017
set sortseed 111017

******************************************************************************
* 1. Dataset prep
******************************************************************************

use "`analysis_data'", clear
keep if qtr == 4
foreach x in t c a {
	gen y2_performance_`x' = y2015_ln_recov_tot_`x' - y2014_ln_recov_tot_`x'
	gen y1_performance_`x' = y2014_ln_recov_tot_`x' - y2013_ln_recov_tot_`x'
}
gen y2014_ln_recov_tot = .
gen y2013_ln_recov_tot = .
gen y2012_ln_recov_tot = .
gen y2014_ln_net_dem = .
gen y2013_ln_net_dem = .
gen y2012_ln_net_dem = .
label var y2014_ln_recov_tot "Log Recovery 2014"
label var y2013_ln_recov_tot "Log Recovery 2013"
label var y2012_ln_recov_tot "Log Recovery 2012"
label var y2014_ln_net_dem "Log Net Demand 2014"
label var y2013_ln_net_dem "Log Net Demand 2013"
label var y2012_ln_net_dem "Log Net Demand 2012"

replace control_y1=. if y2_only==1 

drop if y2_only==1
codebook group_id
drop group_id

preserve
use "Coded Data/150525 TP Analysis Data", clear
drop if qtr!=4
keep group_id circle_id
tempfile new_group_id
save `new_group_id'
restore

merge 1:1 circle_id  using `new_group_id', keep(3) nogen
codebook group_id

tempfile analysis
sa `analysis'

******************************************************************************
* 2. Run regressions and save predictions
******************************************************************************

keep if y2_only==0

*Old

	eststo old_betas: reg y1_performance_t y2013_ln_recov_tot_t y2012_ln_recov_tot_t y2013_ln_net_dem_t y2012_ln_net_dem_t i.group_id if control_y1 & !y2_only, cluster(circle_id)
	predict y1_performance_prediction
	foreach var in y1_performance_t y1_performance_prediction {
	bys group_id: center `var', gen (center_`var')
	}
	gen error=center_y1_performance_t-center_y1_performance_prediction
	summ error if y2_only==0
	drop y1_performance_prediction 
	rename center_y1_performance_prediction  y1_performance_prediction 
	eststo old_y1: reg y1_performance_t y1_performance_prediction i.group_id if y2_only==0, vce(cluster circle_id)
	
	reg y2_performance_t y2013_ln_recov_tot_t y2012_ln_recov_tot_t y2013_ln_net_dem_t y2012_ln_net_dem_t i.group_id if (control_y1 & control_y2), cluster(circle_id)
	predict y2_performance_prediction
	predict resid2, resid
	
	gen zero_base_performance = 0
	
	keep if !y2_only // Save predictions for Y1-only circles
	keep circle_id y1_performance_prediction y2_performance_prediction y1_performance_t
	sa "`output_file_old'", replace

*New
	
	use  `analysis', clear

	preserve
	keep if control_y1==1
	levelsof group_id, local(id_control)
	restore
	foreach i in `id_control' {
	eststo new_betas_g`i': reg y1_performance_t y2013_ln_recov_tot_t y2012_ln_recov_tot_t y2013_ln_net_dem_t y2012_ln_net_dem_t i.group_id if  control_y1==1 & group_id!=`i', cluster(circle_id)
	mat beta_g`i'=e(b)'
	matrix list beta_g`i'
	local b1=beta_g`i'[1,1]
	local b2=beta_g`i'[2,1]
	local b3=beta_g`i'[3,1]
	local b4=beta_g`i'[4,1]
	local b30=beta_g`i'[30,1]
	display `b1' 
	display `b2'
	display `b3'
	display `b4'
	display `b30'
	gen y1_performance_prediction_g`i'=`b1'*y2013_ln_recov_tot_t + `b2'*y2012_ln_recov_tot_t + `b3'*y2013_ln_net_dem_t + `b4'*y2012_ln_net_dem_t +  `b30'
	} 
	gen y1_performance_prediction=.
	foreach i in `id_control' {
	replace y1_performance_prediction=y1_performance_prediction_g`i' if control_y1==1 & group_id==`i'
	} 
	
	preserve
	keep if control_y1==1
	keep partition_id group_id
	duplicates drop
	bys partition_id: gen num_=_n
	reshape wide group_id , i(partition_id) j(num_)
	tempfile partition
	save `partition'
	restore 
	merge m:1  partition_id using `partition', assert(1 3)
	forvalues i=1/10 {
	gen temp`i'=group_id`i'!=.
	}
	egen num_groups=rowtotal(temp*)
	drop if y2_only==1
	gen rand=ceil(runiform(0,num_group))
	levelsof rand, local(id_rand)
	gen control_assigned=.
	foreach i in `id_rand' {
	replace control_assigned=group_id`i' if rand==`i'
	}
	bys group_id: egen min_control_assigned=min(control_assigned)
	replace control_assigned=min_control_assigned
	levelsof control_assigned, local(control_assigned)
	foreach j in `control_assigned' {
	replace y1_performance_prediction=y1_performance_prediction_g`j' if control_y1==0 & control_assigned==`j'
	} 
	summ y1_performance_prediction if !y2_only
	foreach var in y1_performance_t y1_performance_prediction {
	bys group_id: center `var', gen (center_`var')
	}
	gen error=center_y1_performance_t-center_y1_performance_prediction
	summ error if y2_only==0
	drop y1_performance_prediction 
	rename center_y1_performance_prediction  y1_performance_prediction 
	eststo new_y1: reg y1_performance_t y1_performance_prediction i.group_id  if y2_only==0, vce(cluster circle_id)

	set scheme s1color
	hist y1_performance_prediction, title("Distribution of y{subscript:0} across circles") xtitle("Demeaned growth rate at baseline") fraction
	graph export "output/Paper/y0_distribution_paper.pdf", replace
	histogram y1_performance_prediction, by(group_id,col(6)) fraction xtitle("Demeaned growth rate at baseline") 
	graph export "output/Paper/y0_distribution_by_group_paper.pdf", replace

	reg y2_performance_t y2013_ln_recov_tot_t y2012_ln_recov_tot_t y2013_ln_net_dem_t y2012_ln_net_dem_t i.group_id if (control_y1 & control_y2), cluster(circle_id)
	predict y2_performance_prediction
	predict resid2, resid
	
	gen zero_base_performance = 0
	
	preserve
	keep if !y2_only // Save predictions for Y1-only circles
	keep circle_id y1_performance_prediction y2_performance_prediction y1_performance_t
	sa "`output_file_new'", replace
	restore 
	
******************************************************************************
* 3. Draw table
******************************************************************************

 local file base_growth_predictions_betas_paper

* First draw for treatment circles
# delimit ;
esttab new_betas_g1 new_betas_g2 new_betas_g5   new_betas_g6  new_betas_g40 
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	keep(y2013_ln_recov_tot_t y2012_ln_recov_tot_t  y2013_ln_net_dem_t y2012_ln_net_dem_t)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	nostar
	
	mtitles("Group 1" "Group 2" "Group 5" "Group 6"  "Group 40"  ) // Column headings
	
	order(y2013_ln_recov_tot_t y2012_ln_recov_tot_t y2013_ln_net_dem_t y2012_ln_net_dem_t )
	
	stats(r2 N ,
		labels(
			"R^{2}" "N"
		)	
		fmt(
			 "%12.3f" "%12.0f"
		)
	)			
	
	label // Use Variable Labels
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr


** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "OLS regessions of performance on time-lagged performance, using group fixed effects."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by group."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex",  ///
  out("..") aux("auxdir/")  
