/*
Heterogeneity by competitiveness
	- Using basic simulations (i.e. Kunal sims)
	- Using new simulations

Author(s):
	Ismail Khan (2015-)

Date created:
	Mar 1, 2016
*/

*************************************************************
* Initial Setup
*************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

*************************************************************
* Prepare dataset(s)
*************************************************************

* Load and temporarily save Y2 data
use "Coded Data/TP Y2 Analysis Data w Y1 Treatment", clear
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if treatment_y1 == 1
drop if mi(treatment_y1)
gen y1 = 0
label var treatment "Treatment"
label var treatment_y1 "Y1 Treatment"
tempfile y2_data
sa `y2_data'

* Load and temporarily save Y2 data
use "Coded Data/TP Y2 Analysis Data w Y1 Treatment", clear
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if mi(treatment_y1)
gen y1 = 0
*label var treatment "Y2 Treatment"
label var treatment_y1 "Y1 Treatment"
tempfile y2_data_y1_circles
sa `y2_data_y1_circles'

* Load and temporarily save Y1 data
use "Coded Data/150525 TP Analysis Data w Y2 Treatment.dta", clear
drop if litigated == 1
keep if qtr == 4
gen y1 = 1
ren treatment treatment_y1
label var treatment_y1 "Y1 Treatment"
tempfile y1_data
sa `y1_data'

* Create pooled dataset
use `y1_data', clear
append using `y2_data'
gen base_y1_interact = .
tempfile pooled_data
sa `pooled_data'

* Load competitiveness data (using basic simulations)
use "Coded Data/Basic simulation results", clear
egen group_id = group(partition_name group) // * New sims dont have partition names, so we need to match these
quietly tab group_id, gen(group_dummy)
reshape long own_circle_id ranking, i(partition_name group hr_id) j(j)
drop j *weak *mean *same ranking
drop if mi(own_circle_id)
ren own_circle_id circle_id
ren (fraction_better_strict fraction_worse_strict fraction_first_choice) (fb_strict fw_strict ff_choice)

* Add movement dummies
merge 1:1 circle_id using "Coded Data/Y1 Movement Dummies", assert(match) keepusing(any_move no_move strictly_worse_dummy strictly_better_dummy) nogen

* Rename variables for ease
ren strictly_better_dummy move_up
ren strictly_worse_dummy move_down
label var move_up "Move up"
label var move_down "Move down"

* Add temporary variables for interaction term
gen interaction_pr_move_up = .
gen interaction_pr_forced_out = .
gen interaction_pr_any_move = .
gen interaction_returns_to_effort = .
label var interaction_pr_move_up	 		"Y1 Treatment * Pr(Move up)"
label var interaction_pr_forced_out 		"Y1 Treatment * Pr(Move down)"
label var interaction_pr_any_move 			"Y1 Treatment * Pr(Any move)"
label var interaction_returns_to_effort 	"Y1 Treatment * dEudy"

tempfile basic_sim
sa `basic_sim'

	
* Load competitivness data (using new simulations). Use only Full knowledge of P, y
insheet using "output\Transfer simulations/sim_i10000_y1m_fullk.csv", comma clear
ren (v1 v2 v3 v4 v5 v6 v7 v8) (group_id hr_id dEu1dy dEu2dy dEu3dy pr_forced_out pr_no_move pr_move_up)
gen pr_any_move = 1 - pr_no_move
label var pr_move_up "Pr(Move up)"
label var pr_forced_out "Pr(Move down)"
label var pr_any_move "Pr(Any move)"
merge 1:m hr_id group_id using `basic_sim', assert(match) nogen
tempfile sim_data
sa `sim_data'

* Add competitiveness measures to pooled dataset
use `pooled_data', clear
merge m:1 circle_id using `sim_data', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
sa `pooled_data', replace

* Add competitiveness measures to y1 dataset
use `y1_data', clear
merge m:1 circle_id using `sim_data', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
sa `y1_data', replace

* Add competitiveness measures to y2 dataset
use `y2_data', clear
merge m:1 circle_id using `sim_data', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
sa `y2_data', replace

* Add competitiveness measures to y2 dataset
use `y2_data_y1_circles', clear
merge m:1 circle_id using `sim_data', keep(match) nogen // _m == 1 for empty circles, _m == 2 for litigated circles
tempfile y2_data_y1_circles
sa `y2_data_y1_circles', replace


*************************************************************
* Run regressions
*************************************************************

* Y1 full data
use `y1_data', clear
		
replace interaction_pr_any_move = pr_any_move * treatment_y1
replace interaction_pr_forced_out = pr_forced_out * treatment_y1
replace interaction_pr_move_up = pr_move_up * treatment_y1
replace interaction_returns_to_effort = dEu1dy * treatment_y1

* Fisrt stage regressions below

* All Y1 circles
eststo first_pr_any_move : reg any_move	treatment_y1 pr_any_move dEu1dy interaction_pr_any_move	interaction_returns_to_effort, cluster(circle_id)
sum any_move if e(sample) == 1 & treatment_y1 == 0
estadd scalar ymean = `r(mean)'
qui test interaction_pr_any_move == 0
estadd scalar fstat = `r(F)'
eststo first_pr_any_move

* Y2 treatment excluded
eststo firstc_pr_any_move : reg any_move treatment_y1 pr_any_move dEu1dy interaction_pr_any_move interaction_returns_to_effort if treatment_y2 == 0, cluster(circle_id)
sum any_move if e(sample) == 1 & treatment_y1 == 0
estadd scalar ymean = `r(mean)'
qui test interaction_pr_any_move == 0
estadd scalar fstat = `r(F)'
eststo firstc_pr_any_move

* Y2 data (with all y1 circles only)
use `y2_data_y1_circles', clear
foreach x in t c a {	

	gen reg_sample = .
	replace interaction_pr_any_move = pr_any_move * treatment_y1
	replace interaction_returns_to_effort = dEu1dy * treatment_y1

	* Reduced form regressions
	eststo rf_pr_any_move_`x' : reg ln_recov_tot_`x' treatment_y1 pr_any_move dEu1dy interaction_pr_any_move interaction_returns_to_effort base_ln_recov_tot_`x', cluster(circle_id)
	eststo rfc_pr_any_move_`x' : reg ln_recov_tot_`x' treatment_y1 pr_any_move dEu1dy interaction_pr_any_move interaction_returns_to_effort base_ln_recov_tot_`x' if treatment == 0, cluster(circle_id)
	
	* OLS regressions
	eststo ols_pr_any_move_`x' : reg ln_recov_tot_`x' treatment_y1 pr_any_move dEu1dy any_move interaction_returns_to_effort base_ln_recov_tot_`x', cluster(circle_id)
	eststo olsc_pr_any_move_`x' : reg ln_recov_tot_`x' treatment_y1 pr_any_move dEu1dy any_move interaction_returns_to_effort base_ln_recov_tot_`x' if treatment == 0, cluster(circle_id)
	
	* IV regressions & combine models
	eststo iv_pr_any_move_`x' : ivreg ln_recov_tot_`x' treatment_y1 pr_any_move dEu1dy (any_move = interaction_pr_any_move) interaction_returns_to_effort base_ln_recov_tot_`x', cluster(circle_id)
	replace reg_sample = e(sample) == 1
	eststo iv_pr_any_move_`x'
	eststo pr_any_move_`x' :	combine_models2 rf_pr_any_move_`x' iv_pr_any_move_`x' ols_pr_any_move_`x', headings(A B C)
	qui sum ln_recov_tot_`x' if reg_sample == 1 & treatment_y1 == 0
	estadd scalar ymean = `r(mean)'
	qui count if reg_sample == 1
	estadd scalar N = `r(N)'
	eststo pr_any_move_`x'
	
	eststo ivc_pr_any_move_`x' : ivreg ln_recov_tot_`x' treatment_y1 pr_any_move dEu1dy (any_move = interaction_pr_any_move) interaction_returns_to_effort base_ln_recov_tot_`x' if treatment == 0, cluster(circle_id)
	replace reg_sample = e(sample) == 1
	eststo ivc_pr_any_move_`x' 
	eststo prc_any_move_`x' :	combine_models2 rfc_pr_any_move_`x' ivc_pr_any_move_`x' olsc_pr_any_move_`x', headings(A B C)
	qui sum ln_recov_tot_`x' if reg_sample == 1 & treatment_y1 == 0
	estadd scalar ymean = `r(mean)'
	qui count if reg_sample == 1
	estadd scalar N = `r(N)'
	eststo prc_any_move_`x' 
	
	drop reg_sample
}


*************************************************************
* Draw Table: Using Pr(Any Move) only (First Stage)
*************************************************************
 
local file switching_cost_any_move_first
label var dEu1dy "dEudy"

# delimit ;
esttab first_pr_any_move firstc_pr_any_move
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex",
	keep(treatment_y1 pr_any_move dEu1dy interaction_returns_to_effort interaction_pr_any_move)

	b(%12.3f)
	se(%12.3f)

	starlevels(* .10 ** .05 *** .01) // significance levels
	nostar
	
	mtitles("Any move" "Any move") // Column headings

	stats(N ymean fstat,
		labels(
			"N"
			"Mean of Y1 Control group"
			"Y1 Treatment * Pr(Any move) = 0 (F statistic)"
		)	
		fmt(
			"%12.0f" "%12.3f" "%12.3f"
		)
	)	
	
	order(interaction_pr_any_move interaction_returns_to_effort pr_any_move dEu1dy treatment_y1)
	
	mgroups("All circles" "Y2 Treatment excluded",
		pattern(1 1)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)	
	
	label // Use Variable Labels
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "First stage regessions of any move dummy on various regressors."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by circle."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
 


*************************************************************
* Draw Table: Using Pr(Any Move) only (Reduced form, IV, OLS)
*************************************************************
 
local file switching_cost_any_move

# delimit ;
esttab pr_any_move_t pr_any_move_c pr_any_move_a prc_any_move_t prc_any_move_c prc_any_move_a
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	keep(treatment_y1 pr_any_move dEu1dy interaction_returns_to_effort interaction_pr_any_move any_move)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	nostar 
	
	mtitles("Total" "Current" "Arrears" "Total" "Current" "Arrears")
	
	eqlabels(
		"\emph{Panel A: Reduced form}"
		"\emph{Panel B: IV}"
		"\emph{Panel B: OLS}"
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)	

	mgroups("All circles" "Y2 Treatment excluded",
		pattern(1 0 0 1 0 0)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)	
	
	order(any_move interaction_pr_any_move interaction_returns_to_effort pr_any_move dEu1dy treatment_y1)
	
	stats(N ymean,
		labels(
			"N" "Mean of Y1 Control group"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)	
	
	label // Use Variable Labels
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Reduced form, IV, and OLS regessions of Y2 log total recovery on various regressors."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by circle."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

