/* 

Create full interaction table using Y2 Q4 data. Includes RI.
LHS is the time spent in the circle as of Y2 Q3

*/

*************************************************************
* Initial Setup
*************************************************************

clear all
set more off
cap cd "${TP_ANALYSIS}"
do "Do Files/programs/all_programs.do"

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval 
program define add_pval, eclass // Name of the command
syntax,  results(string) pval1(real) pval2(real) pval3(real) indvar1(string) indvar2(string) indvar3(string) // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,3,.) // Opens a space for pvalue
matrix colnames pval="`indvar1'" "`indvar2'"  "`indvar3'" 

matrix pval[1,1]=`pval1' // Defines where the value comes from
matrix pval[1,2]=`pval2' 
matrix pval[1,3]=`pval3'

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* Define a program for storing p values from Rand Inference
*************************************************************

cap prog drop add_pval2
program define add_pval2, eclass // Name of the command
*syntax,  results(string) pval1(real) pval2(real) pval3(real) indvar(string) // Associate p with estimates of y, local pval and indep variable indvar.
syntax,  results(string) pval(real) indvar(string)  // Associate p with estimates of y, local pval and indep variable indvar.

estimates restore `results'

matrix pval=J(1,1,.) // Opens a space for pvalue
matrix colnames pval="`indvar'" 

matrix pval[1,1]=`pval' // Defines where the value comes from

estadd matrix pval pval // Stores the matrix

end

*************************************************************
* Prepare dataset(s)
*************************************************************


* Load and temporarily save Y2 Q4 data
use "Coded Data/TP Y2 Analysis Data w Y1 Treatment", clear
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop if mi(treatment_y1)
replace treatment_y1 = 0 if mi(treatment_y1) // Check this with Ben
gen y1_treat_or_y2_treat = treatment_y1 | treatment
replace y1_treat_y2_treat = treatment_y1 & treatment

* Label variables
label var treatment_y1 			"Y1 Treatment"
label var treatment 			"Y2 Treatment"
label var y1_treat_y2_treat 	"Y1 AND Y2 Treatment"
label var y1_treat_or_y2_treat	"Y1 OR Y2 Treatment"

* Add "Days in Circle"
merge 1:1 circle_id using "Coded Data/Time in Circle as of Y2 Q3", keepusing(time_in_circle any_move) keep(match) nogen

tempfile y2_data
sa `y2_data'

*************************************************************
* Prepare dataset(s) II: Randomization files
*************************************************************

local num 2000

quietly{
forval m = 1/`num' {

use "Coded Data/TP Y2 Analysis Data w Y1 Treatment", clear
drop if litigated == 1 // drop litigated circles
keep if qtr == 4
drop treatment* DEM_sel* REV_sel* group_id
merge 1:1 circle_id using "Coded Data/RI/rand_code_iter", keepusing(treatment_y1_`m'  treatment_y2_`m' DEM_sel_y1_`m' REV_sel_y1_`m' DEM_sel_y2_`m' REV_sel_y2_`m' group_id_`m') 
drop if mi(treatment_y1)
replace treatment_y1 = 0 if mi(treatment_y1) // ?? This does nothing.
label var treatment_y2 "Treatment"
label var DEM_sel_y2 "Demand"
label var REV_sel_y2 "Revenue"
quietly tab group_id, gen(group_dummy)
rename  treatment_y2_`m' treatment_`m'
gen y1_treat_or_y2_treat_`m' = treatment_y1 | treatment_`m'
gen y1_treat_y2_treat_`m' = treatment_y1 & treatment_`m'

* Label variables
label var treatment_y1 				"Y1 Treatment"
label var treatment_`m'				"Y2 Treatment"
label var y1_treat_y2_treat_`m' 	"Y1 AND Y2 Treatment"
label var y1_treat_or_y2_treat_`m'	"Y1 OR Y2 Treatment"

* Add "Days in Circle"
merge 1:1 circle_id using "Coded Data/Time in Circle as of Y2 Q3", keepusing(time_in_circle any_move) keep(match) nogen

tempfile y2_data_`m'
sa `y2_data_`m''
}
}

*************************************************************
* Run regressions
*************************************************************

* Time in Circle on full interaction

	quietly{ // Regressions for randomized treatments
	tempname result_a_rand
	postfile `result_a_rand' b_treatment se_treatment b_treatment_y1 se_treatment_y1 b_y1_treat_y2_treat se_y1_treat_y2_treat using result_a_rand.dta, replace 
	forval m = 1/`num' {
	use `y2_data_`m'', clear
	reg time_in_circle treatment_`m' treatment_y1  y1_treat_y2_treat_`m', cluster(circle_id) // treatment_y1_`m'  y1_treat_y2_treat_`m' 
	post `result_a_rand' (_b[treatment_`m']) (_se[treatment_`m']) (_b[treatment_y1]) (_se[treatment_y1]) (_b[y1_treat_y2_treat_`m']) (_se[y1_treat_y2_treat_`m'])
	}
	postclose `result_a_rand'
	}

	use `y2_data', clear
	eststo result_a : reg time_in_circle  treatment treatment_y1 y1_treat_y2_treat, cluster(circle_id)	
	qui test treatment == treatment_y1
	qui sum time_in_circle if e(sample) == 1 & y1_treat_y2_treat == 0 & treatment == 0 & treatment_y1 == 0
	estadd scalar ymean = `r(mean)'	
	scalar b_treatmentb = _b[treatment]
	estadd scalar b_treatmentb = _b[treatment]
	scalar b_treatment_y1b = _b[treatment_y1]
	estadd scalar b_treatment_y1b = _b[treatment_y1]
	scalar b_y1_treat_y2_treatb = _b[y1_treat_y2_treat]
	estadd scalar b_y1_treat_y2_treatb = _b[y1_treat_y2_treat]
	scalar difb=`=b_treatmentb'-`=b_treatment_y1b'
	estadd scalar difb=`=b_treatmentb'-`=b_treatment_y1b'
	eststo result_a

	use result_a_rand.dta, clear

		preserve
		keep if abs(b_treatment)> abs(`=b_treatmentb') 
		if _N==0{
			local b_treatmentp= 0.001
			}
		else {
			local b_treatmentp = _N / `num' 
			}
		display `b_treatmentp'
		restore
		preserve
		keep if abs(b_treatment_y1)> abs(`=b_treatment_y1b') 
		if _N==0{
			local b_treatment_y1p= 0.001
			}
		else {
			local b_treatment_y1p = _N / `num' 
			}
		display `b_treatment_y1p'
		restore
		preserve
		keep if abs(b_y1_treat_y2_treat)> abs(`=b_y1_treat_y2_treatb') 
		if _N==0{
			local b_y1_treat_y2_treatp= 0.001
			}
		else {
			local b_y1_treat_y2_treatp = _N / `num' 
			}		
		display `b_y1_treat_y2_treatp'
		restore
		
		preserve
		gen dif=b_treatment-b_treatment_y1
		keep if abs(dif)>abs(`=difb')
		scalar eqtest= _N/`num'
		estadd scalar eqtest = _N/`num'
		display `eqtest'
		restore

	add_pval, results(result_a) pval1(`b_treatmentp') pval2(`b_treatment_y1p') pval3(`b_y1_treat_y2_treatp') indvar1(treatment) indvar2(treatment_y1) indvar3(y1_treat_y2_treat) // From the program above
	eststo result_a
	erase result_a_rand.dta

* Time in Circle on y1 treat only

	quietly{ 
	tempname result_b_rand
	postfile `result_b_rand' b_treatment_y1 se_treatment_y1 using result_b_rand.dta, replace 
	forval m = 1/`num' {
	use `y2_data_`m'', clear
	reg time_in_circle treatment_y1, cluster(circle_id)
	post `result_b_rand' (_b[treatment_y1]) (_se[treatment_y1])
	}
	postclose `result_b_rand'
	}

	use `y2_data', clear
	eststo result_b : reg time_in_circle treatment_y1, cluster(circle_id)	
	qui sum time_in_circle if e(sample) == 1 & treatment_y1 == 0
	estadd scalar ymean = `r(mean)'	
	scalar b_treatment_y1b = _b[treatment_y1]
	estadd scalar b_treatment_y1b = _b[treatment_y1]
	eststo result_b
	
	use result_b_rand.dta, clear

		preserve
		keep if abs(b_treatment_y1)> abs(`=b_treatment_y1b') 
		if _N==0{
			local b_treatment_y1p= 0.001
			}
		else {
			local b_treatment_y1p = _N / `num' 
			}
		display `b_treatment_y1p'
		restore

	add_pval2, results(result_b) pval(`b_treatment_y1p') indvar(treatment_y1)
	eststo result_b
	erase result_b_rand.dta

* Any move on full interaction

	quietly{ // Regressions for randomized treatments
	tempname result_c_rand
	postfile `result_c_rand' b_treatment se_treatment b_treatment_y1 se_treatment_y1 b_y1_treat_y2_treat se_y1_treat_y2_treat using result_c_rand.dta, replace 
	forval m = 1/`num' {
	use `y2_data_`m'', clear
	reg any_move treatment_`m' treatment_y1  y1_treat_y2_treat_`m', cluster(circle_id) // treatment_y1_`m'  y1_treat_y2_treat_`m' 
	post `result_c_rand' (_b[treatment_`m']) (_se[treatment_`m']) (_b[treatment_y1]) (_se[treatment_y1]) (_b[y1_treat_y2_treat_`m']) (_se[y1_treat_y2_treat_`m'])
	}
	postclose `result_c_rand'
	}

	use `y2_data', clear
	eststo result_c : reg any_move  treatment treatment_y1 y1_treat_y2_treat, cluster(circle_id)	
	qui test treatment == treatment_y1
	qui sum any_move if e(sample) == 1 & y1_treat_y2_treat == 0 & treatment == 0 & treatment_y1 == 0
	estadd scalar ymean = `r(mean)'	
	scalar b_treatmentb = _b[treatment]
	estadd scalar b_treatmentb = _b[treatment]
	scalar b_treatment_y1b = _b[treatment_y1]
	estadd scalar b_treatment_y1b = _b[treatment_y1]
	scalar b_y1_treat_y2_treatb = _b[y1_treat_y2_treat]
	estadd scalar b_y1_treat_y2_treatb = _b[y1_treat_y2_treat]
	scalar difb=`=b_treatmentb'-`=b_treatment_y1b'
	estadd scalar difb=`=b_treatmentb'-`=b_treatment_y1b'
	eststo result_c
	
	use result_c_rand.dta, clear

		preserve
		keep if abs(b_treatment)> abs(`=b_treatmentb') 
		if _N==0{
			local b_treatmentp= 0.001
			}
		else {
			local b_treatmentp = _N / `num' 
			}
		display `b_treatmentp'
		restore
		preserve
		keep if abs(b_treatment_y1)> abs(`=b_treatment_y1b') 
		if _N==0{
			local b_treatment_y1p= 0.001
			}
		else {
			local b_treatment_y1p = _N / `num' 
			}
		display `b_treatment_y1p'
		restore
		preserve
		keep if abs(b_y1_treat_y2_treat)> abs(`=b_y1_treat_y2_treatb') 
		if _N==0{
			local b_y1_treat_y2_treatp= 0.001
			}
		else {
			local b_y1_treat_y2_treatp = _N / `num' 
			}		
		display `b_y1_treat_y2_treatp'
		restore
		
		preserve
		gen dif=b_treatment-b_treatment_y1
		keep if abs(dif)>abs(`=difb')
		scalar eqtest= _N/`num'
		estadd scalar eqtest = _N/`num'
		display `eqtest'
		restore
		
	add_pval, results(result_c) pval1(`b_treatmentp') pval2(`b_treatment_y1p') pval3(`b_y1_treat_y2_treatp') indvar1(treatment) indvar2(treatment_y1) indvar3(y1_treat_y2_treat) // From the program above
	eststo result_c
	erase result_c_rand.dta

* Any move on y1 treat only

	quietly{ 
	tempname result_d_rand
	postfile `result_d_rand' b_treatment_y1 se_treatment_y1 using result_d_rand.dta, replace 
	forval m = 1/`num' {
	use `y2_data_`m'', clear
	reg any_move treatment_y1, cluster(circle_id)	
	post `result_d_rand' (_b[treatment_y1]) (_se[treatment_y1])
	}
	postclose `result_d_rand'
	}

	use `y2_data', clear
	eststo result_d : reg any_move treatment_y1, cluster(circle_id)	
	qui sum any_move if e(sample) == 1 & treatment_y1 == 0
	estadd scalar ymean = `r(mean)'	
	scalar b_treatment_y1b = _b[treatment_y1]
	estadd scalar b_treatment_y1b = _b[treatment_y1]
	eststo result_d
	
	use result_d_rand.dta, clear

		preserve
		keep if abs(b_treatment_y1)> abs(`=b_treatment_y1b') 
		if _N==0{
			local b_treatment_y1p= 0.001
			}
		else {
			local b_treatment_y1p = _N / `num' 
			}
		display `b_treatment_y1p'
		restore

	add_pval2, results(result_d) pval(`b_treatment_y1p') indvar(treatment_y1)
	eststo result_d
	erase result_d_rand.dta
	
*************************************************************
* Draw table
*************************************************************

local file time_in_circle_rand

# delimit ;
esttab result_c result_d result_a result_b
	using "${TP_PAPER_OUTPUT}/tex/input/`file'_input.tex", 
	keep(treatment treatment_y1 y1_treat_y2_treat)
	cells(b(fmt(%12.3f) star)
	se(fmt(%12.3f) par)
	pval(fmt(%12.3f) par([ ]))
	)

	collabels(none)				
	coeflabels(treatment "Y2 Treatment" treatment_y1 "Y1 Treatment" y1_treat_y2_treat "Y1 AND Y2 Treatment")

	stardrop(treatment treatment_y1 y1_treat_y2_treat)
	
	mtitles("Any move" "Any move" "Days in circle" "Days in circle")
	
	stats(N eqtest ymean,
		labels(
			"N"
			"Y1 Treatment = Y2 Treatment (p-value)"
			"Mean of control group"
		)	
		fmt(
			"%12.0f" 
			"%12.3f"
			"%12.3f"
		)
	)	
	
	label // Use Variable Labels
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off

** WRITE TABLE NOTE

file open tablenote using "${TP_PAPER_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "OLS regessions of number of days in circle or dummy for any move on various treatment regressors."
file write tablenote " LHS variables are calculated over the time period from the beginning of FY2014 to the date of the execution of transfers."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Sample excludes any circles that have been merged or split after ballot."
file write tablenote " Specification controls for baseline values."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by circle."
file write tablenote " Randomization inference based p-values in brackets."

file close tablenote

texout2 "${TP_PAPER_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TP_PAPER_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/")  

