*! Version 2 19feb2014 Wayne Aaron Sandholtz
/*
SUMMARY:
	Hand texout the name of a .tex file (optionally preceded by its path
	relative to Stata's working directory), and texout will embed it in an 
	"\input{}" command inside a wrapper .tex file along with all the necessary
	commands to make it compile-ready (documentclass, usepackage, \begin{table},
	&c).
NB1:
	This program is designed to input .tex files like those produced by Stata's
	esttab command, which are written in the tabular environment by default.
NB2:
	Note that unless the "fragment" option is specified, the input file need not
	actually exist in order for texout to run.  It will write the wrapper .tex
	file which tells the LaTeX compiler where to look for the input file, but 
	it's on you to make sure that file exists.

OPTIONS:
	INPUT -- whatever you put inside these parentheses is what will be inside
	  the "\input{}" command in this .tex file.  I almost made this a required
	  option, but decided not to in case people want to use this program to 
	  write .tex files which stand on their own and aren't wrappers for some 
	  other input file.  Still, I anticipate that in most cases you'll want to 
	  specify what goes inside "\input{}".  The default is "`filename'_input".
	Fragment -- if this option is specified, texout will expect the file it's
	  putting inside "\input{}" to be raw TeX cells, with no environment
	  wrapping them.  So it'll write a tabular environment inside the table
	  environment it already writes by default.  It will also look at the input
	  file you give it -- specifically, the last line in that file which
	  contains at least one "&" -- to determine how many columns are in your
	  table.  That's how it'll know what number to feed to tabular and to
	  the multicolumn{} command that adds the footnotes.
*/

********************************************************************************

cap pr drop texout
pr define texout, rclass
	version 12
	
	local cmdline `"`0'"'
	
	syntax anything [, INPUT(string) Fragment]

	local my = `"`1'"'

	if "`input'" != "" local isin input
	foreach x in my `isin'{
		** Parse the path
		tokenize `"``x''"', parse(/\)
		local tokenlen = 0
		local i = 1
		while `tokenlen' == 0{
			if "``i''" == "" local tokenlen = `i' - 1
			local ++i
		}
		
		** Put together the path
		local `x'dir
		forv i = 1/`= `tokenlen' - 1'{
			if "``i''" == "\" local `i' = "/"
			local `x'dir ``x'dir'``i''
		}

		** Isolate the part of the user input that is just the filename (no path)
		local `x'file = "``tokenlen''"
		
		** Take file extension off myfile if it's there
		gettoken `x'file ext : `x'file, parse(.)
	}
	
	** Recursion check.
	if `"`mydir'`myfile'"' == `"`inputdir'`inputfile'"'{
		di as error "Your output file and the specified input file are the same!"
		di as error "You can't write a tex file to wrap around itself!"
		exit
	}
	
	** Default input value
	if "`input'" == "" local inputfile `myfile'_input
	
	** Fragment option *********************************************************
	
	if "`fragment'" != ""{
	
	** Find number of cells (to insert in the tabular setup and footnote)
		tempname fh
		file open `fh' using "`mydir'`inputdir'`inputfile'.tex", read
		local num = 1
		local datacells = 0
		file read `fh' line`num'
		while r(eof) == 0 {
			file read `fh' line`num'
			di "`line`num''"
			** Tokenize on & and count how many &'s are in this line.
			tokenize `"`line`num''"', parse("&")
			local linecells = 0
			local i = 1
			while "``i''" != ""{
				if "``i''" == "&" local ++linecells
				local ++i
			}
			** Hold onto this number of &'s if it's the biggest yet.
			if `linecells' > `datacells' local datacells = `linecells'
			di "datacells: `datacells'"
			local ++num
		}
		file close `fh'
		if `datacells' == 0{
			di as error "The file you've pointed me to doesn't seem to be &-delimited"
			di as error "like I expect a .tex file to be."
			exit 601
		}		
		local totalcells = `datacells' + 1
		di `totalcells'
		
	** Define the extra lines that need to go in if "fragment" is specified		
		local prefrag1	`"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}		"'
		local prefrag2	`"\begin{tabular}{l*{`datacells'}{c}}				"'
		local prefrag3	`"\toprule											"'

		local postfrag1	`"\bottomrule										"'
		local postfrag2	`"\addlinespace[1mm]								"'
		local postfrag5	`"\end{tabular}										"'
	}
	
	** Write the file **********************************************************
	# delimit ;
	tempname f;
	file open `f' using "`mydir'`myfile'.tex", write replace;
	foreach thing in 
	`"\documentclass[preview, varwidth=\maxdimen, border=10pt]{standalone} 	"'
	`"\usepackage{amsmath}                                                  "'
	`"\usepackage{amsfonts}                                                 "'
	`"\usepackage{booktabs}                                                 "'
	`"\usepackage{titlesec}                                                 "'
	`"                                                                      "'
	`"% This is for word wrap in cells in tables.                           "'
	`"\newcommand{\specialcell}[2][c]{%                                     "'
	`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
	`"                                                                      "'
	`"\titleformat{\section}                                                "'
	`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
	`"                                                                      "'
	`"\begin{document}                                                      "'
	`"\begin{table}[htp]                                                    "'
	`"\centering                                                            "'
	`"\scriptsize                                                           "'
	`"`prefrag1'"'
	`"`prefrag2'"'
	`"`prefrag3'"'
	`"\input{"`inputdir'`inputfile'.tex"}                                  	"'
	`"`postfrag1'"'
	`"`postfrag2'"'
	`"`postfrag5'"'
	`"\end{table}                                                           "'
	`"\end{document}                                                        "'{;
		file write `f' `"`thing'"' _n;
	};
	file close `f';
	# delimit cr
	****************************************************************************
		
	** Return list
	return local cmdline `"`cmdline'"'
	return local myfile "`myfile'"
	return local mydir "`mydir'"
	return local inputfile "`inputfile'"
	return local inputdir "`inputdir'"
	return local fragment "`fragment'"
end


// New version adds features for table notes. Keep in mind for this to work all tables must
// be exported as fragments. The old fragment setting is disabled.

cap pr drop texout2
pr define texout2, rclass
	version 12
	
	local cmdline `"`0'"'
	
	syntax anything [, INPUT(string) NOTES(string)]

	local my = `"`1'"'

	** Process input file
	*-------------------------------
	
	if "`input'" != "" local isin input
	foreach x in my `isin'{
		** Parse the path
		tokenize `"``x''"', parse(/\)
		local tokenlen = 0
		local i = 1
		while `tokenlen' == 0{
			if "``i''" == "" local tokenlen = `i' - 1
			local ++i
		}
		
		** Put together the path
		local `x'dir
		forv i = 1/`= `tokenlen' - 1'{
			if "``i''" == "\" local `i' = "/"
			local `x'dir ``x'dir'``i''
		}

		** Isolate the part of the user input that is just the filename (no path)
		local `x'file = "``tokenlen''"
		
		** Take file extension off myfile if it's there
		gettoken `x'file ext : `x'file, parse(.)
	}
	
	** Recursion check.
	if `"`mydir'`myfile'"' == `"`inputdir'`inputfile'"'{
		di as error "Your output file and the specified input file are the same!"
		di as error "You can't write a tex file to wrap around itself!"
		exit
	}
	
	** Default input value
	if "`input'" == "" local inputfile `myfile'_input
	
	
	** Run the above with the notes file
	*-----------------------------------------------
	
	if "`notes'" != "" local isin notes
	foreach x in my `isin'{
		** Parse the path
		tokenize `"``x''"', parse(/\)
		local tokenlen = 0
		local i = 1
		while `tokenlen' == 0{
			if "``i''" == "" local tokenlen = `i' - 1
			local ++i
		}
		
		** Put together the path
		local `x'dir
		forv i = 1/`= `tokenlen' - 1'{
			if "``i''" == "\" local `i' = "/"
			local `x'dir ``x'dir'``i''
		}

		** Isolate the part of the user input that is just the filename (no path)
		local `x'file = "``tokenlen''"
		
		** Take file extension off myfile if it's there
		gettoken `x'file ext : `x'file, parse(.)
	}
	
	** Recursion check.
	if `"`mydir'`myfile'"' == `"`notesdir'`notesfile'"'{
		di as error "Your output file and the specified input file are the same!"
		di as error "You can't write a tex file to wrap around itself!"
		exit
	}
	
	** Default notes value
	if "`notes'" == "" local notes `myfile'_notes
		
	** Read Table Note ***********************************************************************
	
		tempname tablenotefile
		cap file open `tablenotefile' using "`mydir'`notesdir'`notesfile'.txt", read
		
		if !_rc {
			file read `tablenotefile' noteline
		}
		else {
			di as error "Your specified note file does not exist!"
			exit
		}
		
	** Formatting *********************************************************

	** Find number of cells (to insert in the tabular setup and footnote)
		tempname fh
		file open `fh' using "`mydir'`inputdir'`inputfile'.tex", read
		local num = 1
		local datacells = 0
		file read `fh' line`num'
		while r(eof) == 0 {
			file read `fh' line`num'
			di "`line`num''"
			** Tokenize on & and count how many &'s are in this line.
			tokenize `"`line`num''"', parse("&")
			local linecells = 0
			local i = 1
			while "``i''" != ""{
				if "``i''" == "&" local ++linecells
				local ++i
			}
			** Hold onto this number of &'s if it's the biggest yet.
			if `linecells' > `datacells' local datacells = `linecells'
			di "datacells: `datacells'"
			local ++num
		}
		file close `fh'
		if `datacells' == 0{
			di as error "The file you've pointed me to doesn't seem to be &-delimited"
			di as error "like I expect a .tex file to be."
			exit 601
		}		
		local totalcells = `datacells' + 1
		di `totalcells'
		
	** Write the file **********************************************************
	# delimit ;
	tempname f;
	file open `f' using "`mydir'`myfile'.tex", write replace;
	foreach thing in 
	`"\documentclass[preview, varwidth=\maxdimen, border=10pt]{standalone} 	"'
	`"\usepackage{amsmath}                                                  "'
	`"\usepackage{amsfonts}                                                 "'
	`"\usepackage{booktabs}                                                 "'
	`"\usepackage[flushleft]{threeparttable}                                "'
	`"\usepackage{titlesec}                                                 "'
	`"                                                                      "'
	`"% This is for word wrap in cells in tables.                           "'
	`"\newcommand{\specialcell}[2][c]{%                                     "'
	`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
	`"                                                                      "'
	`"\titleformat{\section}                                                "'
	`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
	`"                                                                      "'
	`"\begin{document}                                                      "'
	`"\begin{table}[htp]                                                    "'
	`"\centering                                                            "'
	`"\scriptsize                                                           "'
	`"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}							"'	
	`"\begin{threeparttable}												"'
	`"\begin{tabular}{l*{`datacells'}{c}}									"'
	`"\toprule																"'
	`"\input{"`inputdir'`inputfile'.tex"}                                  	"'
	`"\bottomrule															"'
	`"\end{tabular}														    "'
	`"\begin{tablenotes}													"'
	`"\item \scriptsize \emph{Notes}: `noteline'							"'
	`"\end{tablenotes}														"'
	`"\end{threeparttable}													"'
	`"\end{table}                                                           "'
	`"\end{document}                                                        "'{;
		file write `f' `"`thing'"' _n;
	};
	file close `f';
	# delimit cr
	
	cap file close `tablenotefile'
	****************************************************************************
		
	** Return list
	return local cmdline `"`cmdline'"'
	return local myfile "`myfile'"
	return local mydir "`mydir'"
	return local inputfile "`inputfile'"
	return local inputdir "`inputdir'"
	return local notesfile "`notesfile'"
	return local notesdir "`notesdir'"
	return local fragment "`fragment'"
end
